@@ -150,8 +150,13 @@ class DiskCache(Cache):
 
     def _document_path(self, document):
         """Internal function to get the disk cache path for DOCUMENT"""
+        version_string = ""
+        if document.version != "latest":
+            version_string = "_" + document.version
         return os.path.join(
-            self.location, document.collection.name, "%s.json" % document.key
+            self.location,
+            document.collection.name,
+            "%s%s.json" % (document.key, version_string),
         )
 
     def contains_document_data(self, document, last_updated_time):
